@@ -119,7 +119,7 @@ void mxbootrepair::installGRUB() {
             if (arch == "i686") { // rename arch to match grub-install target
                 arch = "i386";
             }
-            QString release = getCmdOut("lsb_release -rs");
+            QString release = getCmdOut("grep -oP '(?<=DISTRIB_RELEASE=).*' /etc/lsb-release");
             cmd = QString("chroot %1 grub-install --target=%2-efi --efi-directory=/boot/efi --bootloader-id=MX%3 --recheck\"").arg(path).arg(arch).arg(release);
         }
         proc->start(cmd);
@@ -485,7 +485,7 @@ void mxbootrepair::on_buttonHelp_clicked() {
     QLocale locale;
     QString lang = locale.bcp47Name();
 
-    QString url = "https://mxlinux.org/wiki/help-files/help-mx-boot-repair";
+    QString url = "/usr/share/doc/mx-bootrepair/help/mx-bootrepair.html";
     if (lang.startsWith("fr")) {
         url = "https://mxlinux.org/wiki/help-files/help-r%C3%A9paration-d%E2%80%99amor%C3%A7age";
     }
